from setuptools import setup
from os.path import join, dirname

setup(name='saladware',
      version='0.5.5',
      description='two bears',
      packages=['saladware'],
      author='SALAD37',
      author_email='nonemovo@gmail.com',
      zip_safe=False,
      license="MIT")